==> jmb.bank-0.3.tar.gz: jmb.bank-0.3/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):
    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from jmb.bank.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|json|xml|yml)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='jmb.bank',
    namespace_packages = ['jmb'],
    version = "0.3",
    description='JMB BANK',
    author='ThunderSystems',
    url='http://hg/thundersystems.it/jmb/jmb.bank',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite = "jmb.bank.tests",
    cmdclass={"test": TestRunner},
    install_requires = [
        'setuptools',
        'jmb.core>=0.3.3',
        'jmb.i18n',
        'jmb.organization>=0.3',
        'jmb.address>=0.3.1',
        'jmb.payment>=0.3.1',
        'jmb.currency>=0.3.1',
        'jmb.carriage>=0.3.1',
        'jmb.office>=0.3.1',
        'jmb.vat>=0.3.1',
        'jmb.l10n>=0.3',
        #'jmb.country',
        'django-tinymce',
    ],
    package_data=get_data_files('jmb.bank')
)

==> jmb.bank-0.3.1.tar.gz: jmb.bank-0.3.1/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):

    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from jmb.bank.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|json|xml|yml)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'):
                    del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='jmb.bank',
    namespace_packages=['jmb'],
    version="0.3.1",
    description='jmb.bank',
    author='ThunderSystems',
    url='http://hg/thundersystems.it/jmb/jmb.bank',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="jmb.bank.tests",
    cmdclass={"test": TestRunner},
    install_requires=[
        'setuptools',
        'jmb.core>=0.3.3',
        'jmb.i18n',
        'jmb.organization>=0.3',
        'jmb.address>=0.3.1',
        'jmb.payment>=0.3.1',
        'jmb.currency>=0.3.1',
        'jmb.carriage>=0.3.1',
        'jmb.office>=0.3.1',
        'jmb.vat>=0.3.1',
        'jmb.l10n>=0.3',
        #'jmb.country',
        'django-tinymce',
    ],
    package_data=get_data_files('jmb.bank')
)
